.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#technology-comparisons'>
    </head>

# Technology comparisons

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Panel vs Dash <comparisons/compare_dash>
Panel vs ipywidgets <comparisons/compare_ipywidgets>
Panel vs Voila <comparisons/compare_voila>
Panel vs Streamlit <comparisons/compare_streamlit>
Panel vs JavaScript <comparisons/compare_js>
Panel vs Bokeh <comparisons/compare_bokeh>

```
